translate.convert.po2rc.rerc

Package translate :: Package convert :: Module po2rc :: Class rerc |
[hide private]
[frames] | no frames]

# Class rerc

source code

Instance Methods | [hide private]
__init__(self, templatefile, charset="utf-8", lang=None, sublang=None) | source code
convertstore(self, inputstore, includefuzzy=False) | source code
makestoredict(self, store, includefuzzy=False) make a dictionary of the translations | source code
convertblock(self, block) | source code